@@ -8,6 +8,11 @@ from .models.app import (
     TaskResponse,
     TaskResponseVerbose,
 )
+from .utils.world_model_tools import (
+    create_world_model_tool,
+    make_world_model_tools,
+    search_world_model_tool,
+)
 
 __all__ = [
     "FinchTaskResponse",
@@ -19,4 +24,7 @@ __all__ = [
     "TaskRequest",
     "TaskResponse",
     "TaskResponseVerbose",
+    "create_world_model_tool",
+    "make_world_model_tools",
+    "search_world_model_tool",
 ]
