@@ -13,7 +13,7 @@ from .app import (
     TaskResponse,
     TaskResponseVerbose,
 )
-from .rest import WorldModel, WorldModelResponse
+from .rest import TrajectoryPatchRequest, WorldModel, WorldModelResponse
 
 __all__ = [
     "AuthType",
@@ -29,6 +29,7 @@ __all__ = [
     "TaskRequest",
     "TaskResponse",
     "TaskResponseVerbose",
+    "TrajectoryPatchRequest",
     "WorldModel",
     "WorldModelResponse",
 ]
