@@ -27,10 +27,7 @@ if TYPE_CHECKING:
 MAX_CROW_JOB_RUN_TIMEOUT = 60 * 60 * 24  # 24 hours in sec
 MIN_CROW_JOB_RUN_TIMEOUT = 0  # sec
 
-
-class PythonVersion(StrEnum):
-    V3_11 = "3.11"
-    V3_12 = "3.12"
+DEFAULT_PYTHON_VERSION_USED_FOR_JOB_BUILDS = "3.13"
 
 
 class AuthType(StrEnum):
@@ -420,9 +417,9 @@ class JobDeploymentConfig(BaseModel):
         description="The configuration for the cloud run container.",
     )
 
-    python_version: PythonVersion = Field(
-        default=PythonVersion.V3_12,
-        description="The python version your docker image should build with.",
+    python_version: str = Field(
+        default=DEFAULT_PYTHON_VERSION_USED_FOR_JOB_BUILDS,
+        description="The python version your docker image should build with (e.g., '3.11', '3.12', '3.13').",
     )
 
     agent: Agent | AgentConfig | str = Field(
