@@ -8,7 +8,7 @@ import time
 import types
 from pathlib import Path
 from typing import cast
-from unittest.mock import MagicMock, mock_open, patch
+from unittest.mock import MagicMock, Mock, mock_open, patch
 from uuid import UUID, uuid4
 
 import pytest
@@ -37,10 +37,22 @@ from futurehouse_client.models.rest import (
     UserAgentResponsePayload,
     WorldModel,
 )
+from futurehouse_client.utils.general import create_retry_if_connection_error
+from httpx import (
+    CloseError,
+    ConnectError,
+    ConnectTimeout,
+    HTTPStatusError,
+    NetworkError,
+    ReadError,
+    ReadTimeout,
+    RemoteProtocolError,
+)
 from pytest_subtests import SubTests
+from requests.exceptions import RequestException, Timeout
 
-ADMIN_API_KEY = os.environ["PLAYWRIGHT_ADMIN_API_KEY"]
-PUBLIC_API_KEY = os.environ["PLAYWRIGHT_PUBLIC_API_KEY"]
+ADMIN_API_KEY = os.environ.get("PLAYWRIGHT_ADMIN_API_KEY", "")
+PUBLIC_API_KEY = os.environ.get("PLAYWRIGHT_PUBLIC_API_KEY", "")
 TEST_MAX_POLLS = 100
 
 
@@ -820,13 +832,14 @@ class TestProjectOperations:
             mock_response = MagicMock()
             mock_response.raise_for_status.return_value = None
             mock_response.json.return_value = [
-                {"id": "uuid1", "name": "test"},
-                {"id": "uuid2", "name": "test"},
+                {"id": str(uuid4()), "name": "test"},
+                {"id": str(uuid4()), "name": "test"},
             ]
             mock_get.return_value = mock_response
 
-            with pytest.raises(ProjectError, match="Multiple projects found"):
-                admin_client.get_project_by_name("test")
+            projects = admin_client.get_project_by_name("test")
+            assert isinstance(projects, list)
+            assert len(projects) == 2
 
     def test_add_task_to_project_success(
         self, admin_client: RestClient, test_project_name: str, task_req: TaskRequest
@@ -1146,3 +1159,70 @@ class TestAsyncUserAgentRequestOperations:
 
         with pytest.raises((UserAgentRequestFetchError, PermissionError)):
             await pub_client.aget_user_agent_request(uuid4())
+
+
+def create_mock_http_status_error(message: str, status_code: int) -> HTTPStatusError:
+    """Create a properly mocked HTTPStatusError for testing."""
+    mock_request = Mock()
+    mock_response = Mock()
+    mock_response.status_code = status_code
+
+    return HTTPStatusError(message, request=mock_request, response=mock_response)
+
+
+@pytest.mark.parametrize(
+    ("exception", "should_retry", "test_description"),
+    [
+        (ConnectionError("Connection failed"), True, "connection error"),
+        (Timeout("Request timed out"), True, "timeout error"),
+        (RequestException("Request exception"), True, "request exception"),
+        (ConnectError("Connect error"), True, "httpx connect error"),
+        (ConnectTimeout("Connect timeout"), True, "httpx connect timeout"),
+        (ReadTimeout("Read timeout"), True, "httpx read timeout"),
+        (ReadError("Read error"), True, "httpx read error"),
+        (NetworkError("Network error"), True, "httpx network error"),
+        (RemoteProtocolError("Protocol error"), True, "httpx protocol error"),
+        (CloseError("Close error"), True, "httpx close error"),
+        (FileUploadError("Upload failed"), True, "custom FileUploadError"),
+        (
+            create_mock_http_status_error("Too many requests", 429),
+            True,
+            "429 too many requests",
+        ),
+        (
+            create_mock_http_status_error("Internal server error", 500),
+            True,
+            "500 internal server error",
+        ),
+        (create_mock_http_status_error("Bad gateway", 502), True, "502 bad gateway"),
+        (
+            create_mock_http_status_error("Service unavailable", 503),
+            True,
+            "503 service unavailable",
+        ),
+        (
+            create_mock_http_status_error("Gateway timeout", 504),
+            True,
+            "504 gateway timeout",
+        ),
+        (create_mock_http_status_error("Bad request", 400), False, "400 bad request"),
+        (create_mock_http_status_error("Unauthorized", 401), False, "401 unauthorized"),
+        (create_mock_http_status_error("Forbidden", 403), False, "403 forbidden"),
+        (create_mock_http_status_error("Not found", 404), False, "404 not found"),
+        (ValueError("Invalid value"), False, "value error"),
+        (KeyError("Missing key"), False, "key error"),
+        (RuntimeError("Runtime error"), False, "runtime error"),
+    ],
+)
+def test_retry_logic_conditions(exception, should_retry, test_description):
+    retry_condition = create_retry_if_connection_error(FileUploadError)
+
+    mock_retry_state = Mock()
+    mock_retry_state.outcome = Mock()
+    mock_retry_state.outcome.exception.return_value = exception
+
+    result = retry_condition(mock_retry_state)
+
+    assert result == should_retry, (
+        f"Expected {should_retry} for {test_description}, got {result}"
+    )
